Index: trunk/src/org/openstreetmap/josm/corrector/ReverseWayTagCorrector.java
===================================================================
--- trunk/src/org/openstreetmap/josm/corrector/ReverseWayTagCorrector.java	(revision 6324)
+++ trunk/src/org/openstreetmap/josm/corrector/ReverseWayTagCorrector.java	(revision 6326)
@@ -259,7 +259,5 @@
 
         return applyCorrections(tagCorrectionsMap, roleCorrectionMap,
-                tr("When reversing this way, the following changes to properties "
-                        + "of the way and its nodes are suggested in order "
-                        + "to maintain data consistency."));
+                tr("When reversing this way, the following changes are suggested in order to maintain data consistency."));
     }
 
Index: trunk/src/org/openstreetmap/josm/corrector/TagCorrector.java
===================================================================
--- trunk/src/org/openstreetmap/josm/corrector/TagCorrector.java	(revision 6324)
+++ trunk/src/org/openstreetmap/josm/corrector/TagCorrector.java	(revision 6326)
@@ -71,5 +71,5 @@
 
             final JMultilineLabel label2 = new JMultilineLabel(
-                    tr("Please select which property changes you want to apply."));
+                    tr("Please select which changes you want to apply."));
             label2.setMaxWidth(600);
             p.add(label2, GBC.eop().anchor(GBC.CENTER));
@@ -83,5 +83,5 @@
                 }
 
-                final JLabel propertiesLabel = new JLabel(tr("Properties of "));
+                final JLabel propertiesLabel = new JLabel(tr("Tags of "));
                 p.add(propertiesLabel, GBC.std());
 
Index: trunk/src/org/openstreetmap/josm/gui/tagging/TaggingPreset.java
===================================================================
--- trunk/src/org/openstreetmap/josm/gui/tagging/TaggingPreset.java	(revision 6324)
+++ trunk/src/org/openstreetmap/josm/gui/tagging/TaggingPreset.java	(revision 6326)
@@ -401,5 +401,5 @@
             return cmds.get(0);
         else
-            return new SequenceCommand(tr("Change Properties"), cmds);
+            return new SequenceCommand(tr("Change Tags"), cmds);
     }
 

Index: trunk/src/org/openstreetmap/josm/data/validation/tests/TagChecker.java
===================================================================
--- trunk/src/org/openstreetmap/josm/data/validation/tests/TagChecker.java	(revision 6324)
+++ trunk/src/org/openstreetmap/josm/data/validation/tests/TagChecker.java	(revision 6326)
@@ -65,5 +65,5 @@
 
 /**
  * Check for misspelled or wrong properties
  *
  * @author frsantos
@@ -152,6 +152,5 @@
      */
     public TagChecker() {
-        super(tr("Properties checker :"),
-                tr("This plugin checks for errors in property keys and values."));
+        super(tr("Tag checker :"), tr("This test checks for errors in tag keys and values."));
     }
 
@@ -353,5 +352,5 @@
 
     /**
      * Checks the primitive properties
      * @param p The primitive to check
      */
@@ -742,5 +741,5 @@
             return commands.get(0);
 
-        return new SequenceCommand(tr("Fix properties"), commands);
+        return new SequenceCommand(tr("Fix tags"), commands);
     }
 
@@ -65,5 +65,5 @@
 
 /**
- * Check for misspelled or wrong properties
+ * Check for misspelled or wrong tags
  *
  * @author frsantos
@@ -353,5 +352,5 @@
 
     /**
-     * Checks the primitive properties
+     * Checks the primitive tags
      * @param p The primitive to check
      */